## 1.0.0rc0 (2022-11-04)

### Feat

- **validation**: add quality descriptor (#21)
- **utils**: add unset singleton (#22)

### Refactor

- **zne_strategy**: discontinue frozen dataclass (#20)

## 1.0.0b2 (2022-10-27)

### Feat

- **extrapolation**: add quadratic, cubic, and quartic extrapolators (#18)
- **noise_amplification**: add two-qubit noise amplifier (#19)

## 1.0.0b1 (2022-10-20)

### Feat

- **zne_strategy**: add is_noop check (#15)
- **meta**: allow bypassing ZNE on run (#13)
- **zne_strategy**: add noop constructor (#12)

## 1.0.0b0 (2022-10-17)
